==> scraping-1.0.0-sources.jar: com/tenqube/visual_scraper/constants/Constants.java <==
package com.tenqube.visual_scraper.constants;

/**
 * Created by tenqube on 2018. 4. 9..
 */

public class Constants {

    public static final String USER_AGENT = "Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/57.0.2987.133 Safari/537.36";
    public static class SCRAP_TYPE {

        public static final int PURCHASE = 0;
        public static final int DETAIL_PURCHASE = 1;
        public static final int PRODUCT = 2;
    }

    public static class METHOD_TYPE{
        public static final int GET = 0;
        public static final int POST = 1;
    }
    public static class CONTENT_TYPE{
        public static final int URL_ENCODED = 0;
        public static final int JSON = 1;
        public static final String JSON_KEY= "application/json";
    }
    public static class DYNAMIC_KEY {
        public static final String DYNAMIC_DATE = "dynamicDate";
        public static final String DYNAMIC_END = "dynamicEnd";
        public static final String DYNAMIC_USER_ID_KEY = "dynamicID";
        public static final String DYNAMIC_USER_PW_KEY = "dynamicPW";
        public static final String DYNAMIC_USER_START_DATE_KEY = "dynamicPW";
    }



    public static class MESSAGES{
        public static final String NO_DATA = "no data";
        public static final String INVALID_USER_INFO = "Invalid User Info";
        public static final String PARSING_SUCCESS = "Parsing Success";
        public static final String TIMEOUT_FAIL = "Timeout Fail";
        public static final String PARSING_FAIL = "Parsing FAIL";
        public static final String LOGIN_SUCCESS = "Success LoginPage";
        public static final String PURCHASE_START = "Start scraping Purchase";
        public static final String PURCHASE_END = "done";
        public static final String INVALID_EMAIL_FORMAT = "Invalid Email format";
    }
    public static class STATUSCODE{
        public static final int SUCCESS_CODE =200;
        public static final int FAIL_CODE = 400;
        public static final int INVALID_USER_CODE = 404;

    }
}

==> scraping-1.0.3-sources.jar: com/tenqube/visual_scraper/constants/Constants.java <==
package com.tenqube.visual_scraper.constants;

/**
 * Created by tenqube on 2018. 4. 9..
 */

public class Constants {

    public static final String USER_AGENT = "Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/57.0.2987.133 Safari/537.36";
    public static class SCRAP_TYPE {

        public static final int PURCHASE = 0;
        public static final int DETAIL_PURCHASE = 1;
        public static final int PRODUCT = 2;
    }

    public static class METHOD_TYPE{
        public static final int GET = 0;
        public static final int POST = 1;
    }
    public static class CONTENT_TYPE{
        public static final int URL_ENCODED = 0;
        public static final int JSON = 1;
        public static final String JSON_KEY= "application/json";
    }
    public static class DYNAMIC_KEY {
        public static final String DYNAMIC_DATE = "dynamicDate";
        public static final String DYNAMIC_END = "dynamicEnd";
        public static final String DYNAMIC_USER_ID_KEY = "dynamicID";
        public static final String DYNAMIC_USER_PW_KEY = "dynamicPW";
        public static final String DYNAMIC_ORDER_NUM_KEY = "dynamicOrderNum";
    }



    public static class MESSAGES{
        public static final String NO_DATA = "no data";
        public static final String INVALID_USER_INFO = "Invalid User Info";
        public static final String PARSING_SUCCESS = "Parsing Success";
        public static final String TIMEOUT_FAIL = "Timeout Fail";
        public static final String PARSING_FAIL = "Parsing FAIL";
        public static final String LOGIN_SUCCESS = "Success LoginPage";
        public static final String PURCHASE_START = "Start scraping Purchase";
        public static final String PURCHASE_END = "done";
        public static final String INVALID_EMAIL_FORMAT = "Invalid Email format";
    }
    public static class STATUSCODE{
        public static final int SUCCESS_CODE =200;
        public static final int FAIL_CODE = 400;
        public static final int INVALID_USER_CODE = 404;

    }
}
